@@ -60,12 +60,30 @@ void Dialog_Import_CSV_Progress::import(Dialog_Import_CSV& data_source)
   switch(data_source.get_parser_state())
   {
   case CsvParser::STATE_PARSING:
+  {
     // Wait for the parsing to finish. We do not start importing before the file has been
     // parsed completely since we would not to rollback our changes in case of a
     // parsing error.
-    m_progress_bar->set_text(Glib::ustring::compose(_("Parsing CSV file %1"), Glib::filename_from_uri(data_source.get_file_uri())));
+    
+    std::string filename;
+    #ifdef GLIBMM_EXCEPTIONS_ENABLED
+    try
+    {
+      filename = Glib::filename_from_uri(data_source.get_file_uri());
+    }
+    catch(const Glib::ConvertError& ex)
+    {
+      std::cerr << "Glib::filename_from_uri() failed: " << ex.what() << std::endl;
+    }
+    #else
+    std::auto_ptr<Glib::Error> error;
+    filename = Glib::filename_from_uri(data_source.get_file_uri(), error);
+    #endif
+
+    m_progress_bar->set_text(Glib::ustring::compose(_("Parsing CSV file %1"), filename));
     m_ready_connection = data_source.signal_state_changed().connect(sigc::mem_fun(*this, &Dialog_Import_CSV_Progress::on_state_changed));
     break;
+  }
   case CsvParser::STATE_PARSED:
     begin_import();
     break;
