@@ -125,6 +125,8 @@ Glib::ustring UsesRelationship::get_sql_table_or_join_alias_name(const Glib::ust
 
 Glib::ustring UsesRelationship::get_table_used(const Glib::ustring& parent_table) const
 {
+  //std::cout << "UsesRelationship::get_table_used(): relationship=" << glom_get_sharedptr_name(m_relationship) << "related_relationship=" << glom_get_sharedptr_name(m_related_relationship) << std::endl;
+
   if(m_related_relationship)
     return m_related_relationship->get_to_table();
   else if(m_relationship)
@@ -133,6 +135,62 @@ Glib::ustring UsesRelationship::get_table_used(const Glib::ustring& parent_table
     return parent_table;
 }
 
+Glib::ustring UsesRelationship::get_title_used(const Glib::ustring& parent_table_title) const
+{
+  if(m_related_relationship)
+    return m_related_relationship->get_title_or_name();
+  else if(m_relationship)
+    return m_relationship->get_title_or_name();
+  else
+    return parent_table_title;
+}
+
+Glib::ustring UsesRelationship::get_title_singular_used(const Glib::ustring& parent_table_title) const
+{
+  sharedptr<Relationship> used = m_related_relationship;
+  if(!used)
+    used = m_relationship;
+    
+  if(!used)
+    return Glib::ustring();
+    
+  const Glib::ustring result = used->get_title_singular();
+  if(!result.empty())
+    return result;
+  else
+    return get_title_used(parent_table_title);
+}
+
+Glib::ustring UsesRelationship::get_to_field_used() const
+{
+  if(m_related_relationship)
+    return m_related_relationship->get_to_field();
+  else if(m_relationship)
+    return m_relationship->get_to_field();
+  else
+    return Glib::ustring();
+}
+
+Glib::ustring UsesRelationship::get_relationship_name_used() const
+{
+  if(m_related_relationship)
+    return m_related_relationship->get_name();
+  else if(m_relationship)
+    return m_relationship->get_name();
+  else
+    return Glib::ustring();
+}
+
+bool UsesRelationship::get_relationship_used_allows_edit() const
+{
+  if(m_related_relationship)
+    return m_related_relationship->get_allow_edit();
+  else if(m_relationship)
+    return m_relationship->get_allow_edit();
+  else
+    return false; /* Arbitrary default. */
+}
+
 Glib::ustring UsesRelationship::get_sql_join_alias_name() const
 {
   Glib::ustring result;
@@ -147,13 +205,13 @@ Glib::ustring UsesRelationship::get_sql_join_alias_name() const
     const Glib::ustring field_table_name = relationship->get_to_table();
     if(field_table_name.empty())
     {
-      g_warning("build_sql_select_with_where_clause(): field_table_name is null. relationship name = %s", relationship->get_name().c_str());
+      g_warning("get_sql_join_alias_name(): field_table_name is null. relationship name = %s", relationship->get_name().c_str());
     }
     */
 
     if(get_has_related_relationship_name() && m_related_relationship->get_has_fields())
     {
-      result += ("_" + m_related_relationship->get_name());
+      result += ('_' + m_related_relationship->get_name());
     }
   }
 
