@@ -21,27 +21,38 @@
 #ifndef GLOM_UTILITY_WIDGETS_COMBOENTRY_GLOM_H
 #define GLOM_UTILITY_WIDGETS_COMBOENTRY_GLOM_H
 
-#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
 #include <gtkmm.h>
 #include <libglom/data_structure/field.h>
 #include "comboglomchoicesbase.h"
-#include <gtkmm/builder.h>
+
+#ifdef GLOM_ENABLE_MAEMO
+#include <hildonmm/picker-button.h>
+#include <hildonmm/touch-selector-entry.h>
+#endif //GLOM_ENABLE_MAEMO
 
 namespace Glom
 {
 
 class App_Glom;
 
+/** A Gtk::ComboBoxEntry that can show choices of field values.
+ * Use this when the user should be allowed to enter values directly too,
+ * including values that are not in the choices.
+ */
 class ComboEntryGlom
-: public Gtk::ComboBoxEntry,
+: 
+#ifndef GLOM_ENABLE_MAEMO
+  public Gtk::ComboBoxEntry,
+#else
+  public Hildon::PickerButton,
+#endif
   public ComboGlomChoicesBase
 {
 public:
-  explicit ComboEntryGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
-
   ///You must call set_layout_item() to specify the field type and formatting of the main column.
-  explicit ComboEntryGlom();
+  ComboEntryGlom();
 
   ///You must call set_layout_item() to specify the field type and formatting of the main column.
   explicit ComboEntryGlom(const sharedptr<LayoutItem_Field>& field_second);
@@ -72,9 +83,15 @@ private:
   virtual void on_entry_activate(); //From Gtk::Entry.
   virtual bool on_entry_focus_out_event(GdkEventFocus* event); //From Gtk::Widget
 
+  
+  #ifndef GLOM_ENABLE_MAEMO
   // Note that this is a normal signal handler when glibmm was complied
   // without default signal handlers
   virtual void on_changed(); //From Gtk::ComboBox
+  #else
+  void on_changed(int column);
+  #endif //GLOM_ENABLE_MAEMO
+  
 
   virtual void check_for_change();
 
@@ -83,10 +100,16 @@ private:
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   virtual App_Glom* get_application();
-
+  
+  Gtk::Entry* get_entry();
+  const Gtk::Entry* get_entry() const;
 
   Glib::ustring m_old_text;
   //Gnome::Gda::Value m_value; //The last-stored value. We have this because the displayed value might be unparseable.
+   
+  #ifdef GLOM_ENABLE_MAEMO
+  Hildon::TouchSelectorEntry m_maemo_selector;
+  #endif
 };
 
 } //namespace Glom
