@@ -35,6 +35,12 @@ LabelGlom::LabelGlom()
   init();
 }
 
+LabelGlom::LabelGlom(const Glib::ustring& label, bool mnemonic)
+: m_label(label, mnemonic)
+{
+  init();
+}
+
 LabelGlom::LabelGlom(const Glib::ustring& label, float xalign, float yalign, bool mnemonic)
 : m_label(label, xalign, yalign, mnemonic)
 {
@@ -49,8 +55,9 @@ void LabelGlom::init()
 {
   add(m_label);
   m_label.show();
-  set_events (Gdk::ALL_EVENTS_MASK);
-  set_visible_window (false);
+  set_events(Gdk::ALL_EVENTS_MASK);
+  //This would be more efficient if we were only using the (base) EventBox to get events, 
+  //but we also want to allow changing of the background color, so we don't use it: set_visible_window(false);
 }
 
 App_Glom* LabelGlom::get_application()
@@ -110,8 +117,14 @@ bool LabelGlom::on_button_press_event(GdkEventButton *event)
       return true; //We handled this event.
     }
   }
+
   return Gtk::EventBox::on_button_press_event(event);
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+Gtk::Label* LabelGlom::get_label()
+{
+  return &m_label;
+}
+
 } //namespace Glom
